@@ -961,7 +961,7 @@ our @EXPORT = qw(
 	PPD_VERSION
 );
 
-our $VERSION = '0.55';
+our $VERSION = '0.61';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -1047,6 +1047,19 @@ sub cancelJob
 	return( NETCUPS_cancelJob( $name, $jobid ) );
 }
 
+##----------------------------------------------##
+##  getDescription                              ##
+##----------------------------------------------##
+sub getDescription
+{
+	my $self = shift;
+
+	return( NETCUPS_getDeviceAttribute( $self->getName(), 
+										"printer-info",
+										IPP_TAG_TEXT() ) );
+}
+
+
 ##----------------------------------------------##
 ##  getError                                    ##
 ##----------------------------------------------##
@@ -1081,6 +1094,18 @@ sub getJobs
 	return( NETCUPS_getJobs( $name, $whose, $scope ) );
 }
 
+##----------------------------------------------##
+##  getLocation                                 ##
+##----------------------------------------------##
+sub getLocation
+{
+	my $self = shift;
+
+	return( NETCUPS_getDeviceAttribute( $self->getName(), 
+										"printer-location",
+										IPP_TAG_TEXT() ) );
+}
+
 ##----------------------------------------------##
 ##  getName                                     ##
 ##----------------------------------------------##
@@ -1111,6 +1136,18 @@ sub getOptions
 	return( NETCUPS_getDestinationOptions( $self ) );
 }
 
+##----------------------------------------------##
+##  getUri                                      ##
+##----------------------------------------------##
+sub getUri
+{
+	my $self = shift;
+
+	return( NETCUPS_getDeviceAttribute( $self->getName(), 
+										"device-uri",
+										IPP_TAG_URI() ) );
+}
+
 ##----------------------------------------------##
 ##  printFile                                   ##
 ##----------------------------------------------##
@@ -1174,11 +1211,17 @@ my $dest->cancelJob( $jobid );
 
 Method to chancel a job sent to this destination.
 
+=item B<getDescription>
+
+my $description = $dest->getDescription();
+
+Provides the description string associated with this printer.
+
 =item B<getError>
 
 my $error = $dest->getError();
 
-Utility method for returning the last error that occured.
+Utility method for returning the last error that occurred.
 
 =item B<getName>
 
@@ -1200,6 +1243,10 @@ This method will return an array of job identifiers.  $whose is 0 for
 all users and 1 is just for the selected user.  $scope is -1 for all 
 jobs, 0 for active jobs and 1 for completed jobs.
 
+=item B<getLocation>
+
+Returns the location string for this destination.
+
 =item B<getOptionValue>
 
 my $value = $dest->getOptionValue( $name );
@@ -1221,6 +1268,13 @@ I know this is the method that you have been looking for.  This is
 what you will use to send a file to handled by the destination.  You
 must provide the name of the file and a title for the job.
 
+=item B<getUri>
+
+my $uri = $dest->getUri();
+
+This function returns the device URI of a destination.
+For example, a network printer might appear as socket://192.168.1.1
+
 =back
 
 =head1 SEE ALSO
@@ -1229,8 +1283,9 @@ L<Net::CUPS>, L<Net::CUPS::PPD>, L<Net::CUPS::IPP>
 
 =head1 SUPPORT
 
-Support for this module and other software developed by 
-Dracken Technology, Inc can be found at http://www.dracken.com/.
+Net::CUPS is currently maintained by Stefan Seifert <NINE@cpan.org>.
+The Github repository for this project is at
+L<https://github.com/niner/perl-Net-CUPS>. Pull requests are welcome.
 
 =head1 AUTHOR
 
@@ -1240,7 +1295,7 @@ Dracken Technology, Inc. (http://www.dracken.com/)
 
 Copyright (c) 2003-2005 David Hageman 
 
-Copyright (c) 2006-2007 Dracken Technology, Inc.
+Copyright (c) 2006-2009 Dracken Technology, Inc.
 
 All rights reserved.
 
